import { axisLeft,
        axisBottom,
        select,
        csv,
        format,
        scaleLinear,
        scaleBand, 
        max } from 'd3';

const svg = select('svg');
const div = select("body").append("div").attr("class", "tooltip");


const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const yValue = d => d.country
  const xValue = d => d.population
  const margin = {top:20,right:40, bottom:20, left:150}
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth]);
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0,innerHeight])
  	.padding(0.04)
  
  const g = svg.append("g")
  	.attr("transform", "translate("+margin.left+","+margin.top+")")
  
  g.append("g").call(axisLeft(yScale));    
  g.append("g").call(axisBottom(xScale).tickFormat(format("s")))
  	.attr("transform", "translate(0,"+innerHeight+")");
  
  g.selectAll("rect").data(data)
  	.enter().append("rect")
  		.attr("y", d => yScale(yValue(d)))
  		.attr("width", d => xScale(xValue(d)))
  		.attr("height", yScale.bandwidth())
  		.on("mouseover", function(d){
    		console.log(event.pageY)
    		div.style("opacity",0.8)
    		div.style("top", event.pageY+"px")
    		div.style("left", event.pageX+"px")
    		div.text(d.population)  		
  		})
  		.on("mouseout", function(d){
  			div.style("opacity",0)
  		}
  
  
};

csv("data.csv").then(data=>{
  data.forEach(d=>{
  	d.population = +d.population *1000;
  })
    render(data)
})